==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/cognitiveservices/kotlin/inputs/IpRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cognitiveservices.kotlin.inputs

import com.pulumi.azurenative.cognitiveservices.inputs.IpRuleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * A rule governing the accessibility from a specific ip address or ip range.
 * @property value An IPv4 address range in CIDR notation, such as '124.56.78.91' (simple IP address) or '124.56.78.0/24' (all addresses that start with 124.56.78).
 */
public data class IpRuleArgs(
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.cognitiveservices.inputs.IpRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.cognitiveservices.inputs.IpRuleArgs =
        com.pulumi.azurenative.cognitiveservices.inputs.IpRuleArgs.builder()
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IpRuleArgs].
 */
@PulumiTagMarker
public class IpRuleArgsBuilder internal constructor() {
    private var `value`: Output<String>? = null

    /**
     * @param value An IPv4 address range in CIDR notation, such as '124.56.78.91' (simple IP address) or '124.56.78.0/24' (all addresses that start with 124.56.78).
     */
    @JvmName("aljgwbtqfhbryqst")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value An IPv4 address range in CIDR notation, such as '124.56.78.91' (simple IP address) or '124.56.78.0/24' (all addresses that start with 124.56.78).
     */
    @JvmName("vryluowayikpkaab")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): IpRuleArgs = IpRuleArgs(
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/cognitiveservices/kotlin/inputs/IpRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cognitiveservices.kotlin.inputs

import com.pulumi.azurenative.cognitiveservices.inputs.IpRuleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * A rule governing the accessibility from a specific ip address or ip range.
 * @property value An IPv4 address range in CIDR notation, such as '124.56.78.91' (simple IP address) or '124.56.78.0/24' (all addresses that start with 124.56.78).
 */
public data class IpRuleArgs(
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.cognitiveservices.inputs.IpRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.cognitiveservices.inputs.IpRuleArgs =
        com.pulumi.azurenative.cognitiveservices.inputs.IpRuleArgs.builder()
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IpRuleArgs].
 */
@PulumiTagMarker
public class IpRuleArgsBuilder internal constructor() {
    private var `value`: Output<String>? = null

    /**
     * @param value An IPv4 address range in CIDR notation, such as '124.56.78.91' (simple IP address) or '124.56.78.0/24' (all addresses that start with 124.56.78).
     */
    @JvmName("fqdlrcpgnvpwquqd")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value An IPv4 address range in CIDR notation, such as '124.56.78.91' (simple IP address) or '124.56.78.0/24' (all addresses that start with 124.56.78).
     */
    @JvmName("pssoaskawytoldvu")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): IpRuleArgs = IpRuleArgs(
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}
